 /* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

#ifndef COMMON_H
#define COMMON_H

/*lint ++flb "Enter library region" */

#include <stdbool.h>
#include <stdint.h>
#include <string.h>

#include "nrf.h"


typedef struct struct_system_flags_t
{
  uint32_t gps_data_received   : 1; // recv'd sentence from GPS receiver
  uint32_t uif_cmd_received    : 1; // user interface command received
  uint32_t uif_cmd_error       : 1; // user interface command error
  uint32_t unused3             : 1;
  uint32_t unused4             : 1;
  uint32_t unused5             : 1;
  uint32_t unused6             : 1;
  uint32_t unused7             : 1;
  uint32_t unused8             : 1;
  uint32_t unused9             : 1;
  uint32_t unused10            : 1;
  uint32_t unused11            : 1;
  uint32_t unused12            : 1;
  uint32_t unused13            : 1;
  uint32_t unused14            : 1;
  uint32_t unused15            : 1;
  uint32_t unused16            : 1;
  uint32_t unused17            : 1;
  uint32_t unused18            : 1;
  uint32_t unused19            : 1;
  uint32_t unused20            : 1;
  uint32_t unused21            : 1;
  uint32_t unused22            : 1;
  uint32_t unused23            : 1;
  uint32_t unused24            : 1;
  uint32_t unused25            : 1;
  uint32_t unused26            : 1;
  uint32_t unused27            : 1;
  uint32_t unused28            : 1;
  uint32_t unused29            : 1;
  uint32_t unused30            : 1;
  uint32_t unused31            : 1;
} struct_system_flags; 

/*
typedef union union_system
{
  uint32_t union_bits;
  struct_system_flags system_flags;
} u_system_flags;
*/

typedef enum{
  TRACKING_MODE = 0,
  HOME_MODE
}SYSTEM_MODE;

//*****************************************************************************
// GPS

// GPS UART receive buffer length
#define GPS_RX_BUFF_LEN   75

// GPS NEMA ASCII sentence code (i.e. GPxxx)
// ex. $GPGLL,3019.47491,N,09744.95624,W,153928.00,A,A*79
#define GPS_CODE_LEN	    6							

//*****************************************************************************
// GPIO Mappings

// UART - There is only a single UART module.  The GPS reciever and 
//        command line interface will share the module.
#define UART_GPS_TX_PIN         9
#define UART_GPS_RX_PIN         11
#define UART_CMD_IF_TX_PIN      0 
#define UART_CMD_IF_RX_PIN      4

// LED
#define LED0_PIN                18
#define LED1_PIN                19


// SPI

// I2C


//*****************************************************************************
// UART Details
#define UART_BAUDRATE    UART_BAUDRATE_BAUDRATE_Baud9600   // nrf51_bitfields.h
#define UART_RX_BUFF_LEN      75

//*****************************************************************************
// I2C Details

//*****************************************************************************
// SPI Details


typedef union UU16
{
  uint16_t U16;
  uint16_t S16;
  uint8_t U8[2];
  uint8_t S8[2];
} UU16;

// used with UU16
#define LSB 0
#define MSB 1

#ifdef	FALSE
#undef	FALSE
#endif
#define FALSE	(0)

#ifdef	TRUE
#undef	TRUE
#endif
#define	TRUE	(1)

#ifdef	NULL
#undef	NULL
#endif
#define NULL	(0)

#ifdef  ON
#undef  ON
#endif
#define ON      (1)

#ifdef  OFF
#undef  OFF
#endif
#define OFF     (0)

/* @file
* @brief Common header file for generic macros and definitions
 *
 */

/*
 * GPIO glue macros, this can be used to define a pin number in source/header file and use that macro for pin
 * configuration using this expansion.
 * example:
 * #define RESET_PIN    8
 * NRF_GPIO->PINCNF(RESET_PIN) = XXX  ;  // Expanded NRF_GPIO->PIN_CNF[8] = XXX
 */
#define PINX_GLUE(x, y, z)       x##y##_##z            /*!< first level glue for pin macros */
#define PINCNF(p)                PINX_GLUE(PIN,p,CNF)  /*!< gpio configure pin number 'p' */
#define PINOUT(p)                PINX_GLUE(PIN,p,OUT)  /*!< gpio out pin number 'p' */

/*lint --flb "Leave library region" */
#endif
