#include "nrf.h"
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "common.h"
#include "leds.h"
#include "uart.h"

//*****************************************************************************
// Description: 
// Input:   None
// Output:  None
//
void gpiote_disable(void)
{
  NVIC_DisableIRQ(GPIOTE_IRQn);
  NRF_GPIOTE->CONFIG[0] = 0;

  // Ensure there are no pending events
  NRF_GPIOTE->EVENTS_IN[0] = 0;

  NRF_GPIOTE->INTENCLR = GPIOTE_INTENCLR_IN0_Enabled << GPIOTE_INTENCLR_IN0_Pos;
}

//*****************************************************************************
// Description: 
// Input:   None
// Output:  None
//
void gpiote_init(void)
{
  nrf_gpio_cfg_input(UART_CMD_IF_RX_PIN, NRF_GPIO_PIN_NOPULL);

  // Enable interrupt:
  NVIC_EnableIRQ(GPIOTE_IRQn);
  
  NRF_GPIOTE->CONFIG[0] =  (GPIOTE_CONFIG_POLARITY_Toggle << GPIOTE_CONFIG_POLARITY_Pos)
              | (UART_CMD_IF_RX_PIN << GPIOTE_CONFIG_PSEL_Pos)
              | (GPIOTE_CONFIG_MODE_Event << GPIOTE_CONFIG_MODE_Pos);

  // Ensure there are no pending events
  NRF_GPIOTE->EVENTS_IN[0] = 0;
  
  NRF_GPIOTE->INTENSET = GPIOTE_INTENSET_IN0_Set << GPIOTE_INTENSET_IN0_Pos;
}

//*****************************************************************************
// Description: 
// Routines to handle switching UART from GPS pins to Command Interface (CI).
// When the user hits a key from the terminal interface, it will generate an 
// interrupt which will switch the GPIO pins the UART is using for the GPS
// receiver to the pins for the CI.  When the user is done using the CI, they
// will enter a commmand that will switch it back to the GPS pins.
// Input:   None
// Output:  None
//
void GPIOTE_IRQHandler(void)
{
  // Event causing the interrupt must be cleared
  if ((NRF_GPIOTE->EVENTS_IN[0] == 1) && (NRF_GPIOTE->INTENSET & GPIOTE_INTENSET_IN0_Msk))
  {
    NRF_GPIOTE->EVENTS_IN[0] = 0;
  }

  // Config uart to use other pins to ouput recv'd gps sentence
  uart_command_interface_init();
  
  led1_toggle();
}

// end of file
